Subgraph

Struct Subgraph 

pub struct Subgraph<G, S = ()>
where G: GraphBase,
{ /* private fields */ }
A subgraph of a graph as determined by the vertex and edge predicates.

The vertex or edge presence determination is done lazily. This has a performance impact on some operations that are usually very fast.

Examples

use gryf::{
    adapt::Subgraph,
    core::{facts, marker::Undirected, EdgeSet, VertexSet},
    Graph,
};

let vertices = 0..10;

let mut graph = Graph::<u32, (), Undirected>::with_capacity(
    vertices.len(),
    facts::complete_graph_edge_count::<Undirected>(vertices.len()),
);
graph.extend_with_vertices(vertices);
graph.connect_vertices(|_, _| Some(()));

assert_eq!(graph.vertex_count(), 10);
assert_eq!(graph.edge_count(), 55);

// Subgraph with only "even" vertices.
let subgraph = Subgraph::new(&graph).filter_vertex(|v, g, _| g[v] % 2 == 0);

assert_eq!(subgraph.vertex_count(), 5);
assert_eq!(subgraph.edge_count(), 15);

Implementations

Source

impl<G> Subgraph<G>
where G: GraphBase,

pub fn new(graph: G) -> Self

Creates a new subgraph of the given graph.

Specify the subset of vertices and/or edges by filter_vertex and filter_edge, respectively. If neither is defined, the subgraph represents the full original graph.

If you need some owned additional state for determining the subsets, use the Subgraph::with_state constructor.

Source

impl<G, S> Subgraph<G, S>
where G: GraphBase,

pub fn with_state(graph: G, state: S) -> Self

Creates a new subgraph of the given graph and a state to be used in the predicates.

Specify the subset of vertices and/or edges by filter_vertex and filter_edge, respectively. If neither is defined, the subgraph represents the full original graph.

If you don’t need any state for determining the subsets, use the Subgraph::new constructor.

pub fn into_inner(self) -> G

Returns the original graph.

pub fn filter_vertex<F>(self, predicate: F) -> Self
where F: Fn(&G::VertexId, &G, &S) -> bool + 'static,

Specifies the subset of vertices by a predicate.

The predicate takes the vertex ID, the original graph and the state that was passed in via Subgraph::with_state (if any).

If you run into “something may not live long enough” compiler error due to 'static lifetime bound on the predicate, pass the borrowed value as part of the state via Subgraph::with_state and access it through the last argument of the predicate.

pub fn filter_edge<F>(self, predicate: F) -> Self
where F: Fn(&G::EdgeId, &G, &S) -> bool + 'static,

Specifies the subset of edges by a predicate.

The predicate takes the edge ID, the original graph and the state that was passed in via Subgraph::with_state (if any).

If you run into “something may not live long enough” compiler error due to 'static lifetime bound on the predicate, pass the borrowed value as part of the state via Subgraph::with_state and access it through the last argument of the predicate.