DfsEvent

Enum DfsEvent 

pub enum DfsEvent<G>
where G: GraphBase,
{ Open { vertex: G::VertexId, time: Time, }, TreeEdge { from: G::VertexId, to: G::VertexId, edge: G::EdgeId, }, BackEdge { from: G::VertexId, to: G::VertexId, edge: G::EdgeId, }, CrossForwardEdge { from: G::VertexId, to: G::VertexId, edge: G::EdgeId, }, Close { vertex: G::VertexId, time: Time, }, }
Depth-first search visitor event.

Use DfsEvents visitor to traverse a graph by reporting DFS events.

Examples

See DfsEvents for examples.

Variants



Open

A new vertex was discovered.

Fields

vertex: G::VertexId

Discovered vertex.

time: Time

Discovering time.



TreeEdge

An edge of the tree formed by the traversal.

Fields

from: G::VertexId

Source endpoint of the edge.

to: G::VertexId

Target endpoint of the edge.

edge: G::EdgeId

Edge ID.



BackEdge

An edge to an already closed vertex.

Presence of a back edge indicates a cycle in the graph.

Fields

from: G::VertexId

Source endpoint of the edge.

to: G::VertexId

Target (closed) endpoint of the edge.

edge: G::EdgeId

Edge ID.



CrossForwardEdge

An edge to an already discovered but not yet closed vertex.

Cross edge is an edge between vertices in different “branches” of the traversal tree. Forward edge is an edge between vertices in the same “branch” of the traversal tree. When the discover time of the from vertex is higher than to vertex, it’s cross edge, otherwise it’s forward edge.

In undirected graphs there is no concept of cross or forward edges.

Fields

from: G::VertexId

Source endpoint of the edge.

to: G::VertexId

Target (closed) endpoint of the edge.

edge: G::EdgeId

Edge ID.



Close

All edges from the vertex have been reported.

Fields

vertex: G::VertexId

Closed vertex.

time: Time

Closing time.