pub enum DfsEvent<G>where
G: GraphBase,{
Open {
vertex: G::VertexId,
time: Time,
},
TreeEdge {
from: G::VertexId,
to: G::VertexId,
edge: G::EdgeId,
},
BackEdge {
from: G::VertexId,
to: G::VertexId,
edge: G::EdgeId,
},
CrossForwardEdge {
from: G::VertexId,
to: G::VertexId,
edge: G::EdgeId,
},
Close {
vertex: G::VertexId,
time: Time,
},
}Expand description
Variants
Open
A new vertex was discovered.
TreeEdge
An edge of the tree formed by the traversal.
Fields
BackEdge
An edge to an already closed vertex.
Presence of a back edge indicates a cycle in the graph.
Fields
CrossForwardEdge
An edge to an already discovered but not yet closed vertex.
Cross edge is an edge between vertices in different “branches” of the
traversal tree. Forward edge is an edge between vertices in the same
“branch” of the traversal tree. When the discover
time of the from vertex is higher than to
vertex, it’s cross edge, otherwise it’s forward edge.
In undirected graphs there is no concept of cross or forward edges.
Fields
Close
All edges from the vertex have been reported.